fedex.printers.unix

Package fedex :: Package printers :: Module unix |
[hide private]
[frames] | no frames]

# Module unix

source code

This module provides a label printing wrapper class for Unix-based installations. By "Unix", we mean Linux, Mac OS, BSD, and various flavors of Unix.

Classes | [hide private]
| DirectDevicePrinter This class pipes the label data directly through a /dev/* entry.

Variables | [hide private]
| __package__ = ``'``fedex.printers``'``